#include <stdio.h>
#include <vector>
#include <cstring>
#include <cassert>
#include <cmath>
#define FOR(q, n) for(int q=0; q<n ;q++)

using namespace std;

const int MAX_ROWS = 40;
const int MAX_COLS = 70;
#define BLANK '.'
char output[MAX_ROWS][MAX_COLS];

/**
 * Clears output
 */
void init_output() {
  FOR(q, MAX_ROWS) {
    FOR(w, MAX_COLS) {
      output[q][w] = BLANK;
    }
  }
}

/**
 * Write current output buffer to output
 */
void write_output() {
  int last_row = 0;
  int last_col = 0;
  FOR(q, MAX_ROWS) {
    FOR(w, MAX_COLS) { 
      if (output[q][w] != BLANK) {
        last_row = max(last_row, q);
        last_col = max(last_col, w);
      }
    }
  }
  for (int q = 0; q <= last_row; q++) {
    for (int w = 0; w <= last_col; w++) {
      printf("%c", output[q][w]);
    }
    printf("\n");
  }
}

/**
 * Parses character and returns the digit
 */
int parse_digit(char c) {
  assert(c >= '0' && c <= '9');
  return c - '0';
}

/**
 * Splits input into pairs of digits, starting at decimal point
 *
 * @param before pairs of digits before decimal point in order from first to last
 * @param after pairs of digits after decimal point in order from first to last
 */
void split_input(const char* input, vector<int>& before, vector<int>& after) {
  int pos = -1;
  int len = strlen(input);

  FOR(q, len) {
    if (input[q] == '.') {
      assert(pos == -1);
      pos = q;
    }
  }

  if (pos == -1) {
    pos = len;
    len++;
  }

  int current = 0; // current position
  if (pos % 2 == 1) {
    before.push_back(parse_digit(input[0]));
    current++;
  }

  while (current != pos) {
    before.push_back(10 * parse_digit(input[current]) + parse_digit(input[current + 1]));
    current += 2;
  }

  current++;
  while (current < len - 1) {
    after.push_back(10 * parse_digit(input[current]) + parse_digit(input[current + 1]));
    current += 2;
  }
  if (len  == current + 1 ) {
    after.push_back(10 * parse_digit(input[current]));
    current++;
  }
  assert(current == len);
}

/**
 * Writes the digit into specified place
 *
 * @param row value -1 means "ignore this operation"
 */
void write_digit(int row, int col, int digit) {
  assert(row > -1);
  assert(col >= 0);
  assert(row < MAX_ROWS);
  assert(col < MAX_COLS);
  assert(0 <= digit && digit < 10);
  if (row >= 0) {
    output[row][col] = '0' + digit;
  }
}

/**
 * Writes the pair to the output
 *
 * @param row to whih we want to write. -1 means that the number won't be
 *  (but the function will still return the length of the number)
 * @param col_end last column which should be used, number will be right-aligned
 * to this position
 * @param zeroes should we write "0x" insted of "x" ?
 *
 * @returns length of the number written
 */
int write_pair(int row, int col_end, int value, bool zeroes) {
  assert(value >= 0);
  assert(value < 100); // should be pair
  int len = 1;
  write_digit(row, col_end, value % 10);
  if (zeroes || (value >= 10)) {
    write_digit(row, col_end - 1, value / 10);
    len++;
  }
  return len;
}

int draw_sqrt_and_input(const vector<int>& data)
{
  assert(data.size() > 0);

  output[1][0] = '_';
  output[2][1] = '\\';
  output[2][2] = '/';

  int col_end = 4 + (data[0] >= 10);
  write_pair(2, col_end, data[0], false);
  for (int i = 1; i < data.size(); i++) {
    col_end += 3;
    write_pair(2, col_end, data[i], true);
  }

  for (int i = 3; i < col_end + 2; i++) {
    output[1][i] = '-';
  }
  output[2][col_end + 2] = '`';
  return col_end + 3;
}

/**
 * Writes comment in form "321 x 321 = 12345" to the specified row
 * starting at position col
 * Warning, overwrites one character after the output
 */
void write_comment(int row, int col, long long int a, long long int b) {
  assert(a * b >= 0);
  assert(a >= 0);
  assert(b >= 0);
  int cnt = sprintf(output[row] + col, "%d.x.%d.=.%d", a, b, a*b);
  output[row][col+cnt] = BLANK; // get rid of 0 terminator
}

/**
 * Writes integer in format "1 23 45 67"
 * to specified row such that the number will end at position
 * last_col
 */
int write_integer(int row, int last_col, long long int value) {
  int len = 0;
  assert(value >= 0);
  while (value >= 100) {
    int l = write_pair(row, last_col - len, value %  100, 1);
    assert(l == 2);
    value /= 100;
    len += 3;
  }
  len += write_pair(row, last_col - len, value, 0);
  return len;
}

/**
 * @param row
 * @param last_col
 * @param min_length -- minimal length of underlines
 * @param last_value previous value (result of subtraction)
 * @param value to be subtracted
 *
 * @returns the length of the last_value - value
 */
int write_subtract(int row, int last_col, int min_length, 
    long long int last_value, long long int value) {
  int d;
  d = write_integer(row, last_col, value);
  output[row][last_col - d] = '-';
  d++;
 
  min_length = std::max(min_length, d);

  // underline
  for (int i = last_col - min_length + 1; i <= last_col; i++) {
    output[row + 1][i] = '-';
  }
  // write result
  int l;
  l = write_integer(row + 2, last_col, last_value - value);
  return l;
}


void solve() {
  const int MAX_INPUT = 100;
  char input[MAX_INPUT];
  vector<int> before;
  vector<int> after;
  vector<int> pairs;
  
  scanf("%s", input);
  split_input(input, before, after);

  pairs.insert(pairs.end(), before.begin(), before.end());
  pairs.insert(pairs.end(), after.begin(), after.end());
  assert(!pairs.empty());

  int comment_col;
  comment_col = draw_sqrt_and_input(pairs);

  /** align is last position */
  int align = 4 + (pairs[0] >= 10);

  if (strstr(input, ".") != NULL) {
    int decimal_pos = (before.size() - 1) * 3 + align + 1;
    output[0][decimal_pos] = ','; // in result
    output[2][decimal_pos] = ','; // in input
  }
  // skip leading zeroes
  while (!pairs.empty() && pairs[0] == 0) {
    output[0][align] = '0';
    align += 3;
    pairs.erase(pairs.begin());
  }
  // if the input is zero, there is nothing to do
  if (pairs.empty()) {
    return;
  }

  assert(pairs.size() > 0);

  int first_digit = (int) (sqrt(pairs[0] + 0.001));
  int pos = 1;
  long long int current = pairs[0];
  long long int result = first_digit;
  int current_len = 1 + (pairs[0] >= 10);

  int row = 3;
  write_comment(row, comment_col, first_digit, first_digit);
  write_pair(0, align, first_digit, false);
  current_len = 3 + write_subtract(row, align, current_len, current, first_digit * first_digit);
  current -= first_digit * first_digit;
  if (current == 0) {
    current_len = 2; // ignore leading zero (and space)
  }

  while (pos < pairs.size()) {
    align += 3;
    row += 3;
    current = current * 100 + pairs[pos];
    // drop down the next pair
    write_pair(row - 1, align, pairs[pos], 1);
    // find the approximation of next digit of the result
    int i = 0;
    while ((result * 20 + i) * i <= current) {
      i++;
    }
    --i;
    // the next digit of the result
    write_pair(0, align, i, false);
    //
    long long int intermediary = (result * 20 + i) * i;
    write_comment(row, comment_col, result * 20 + i, i);
    current_len = write_subtract(row, align, current_len, current, intermediary) + 3;
    current -= intermediary;
    if (current == 0) {
      current_len = 2;
    }
    result = result * 10 + i;
    pos++;
  }
}


int main() {
  int t;
  scanf("%d", &t);
  for (int q = 0; q < t; q++) {
    if (q) printf("\n");
    init_output();
    solve();
    write_output();
  }
}
